@@ -130,7 +130,7 @@ def create_report(true_data, eval_data, index2latex, n, merge=True):
             wrong.append(known)
     classification_error = (len(wrong) / float(len(wrong) + len(correct)))
     logging.info("Classification error (n=%i, MER=%r): %0.4f (%i of %i wrong)",
-                 n, merge, classification_error, len(eval_data), len(wrong))
+                 n, merge, classification_error, len(wrong), len(eval_data))
 
     # Get the data
     errors_by_correct_classification = DefaultOrderedDict(list)
